@@ -13,19 +13,7 @@ from bs4 import BeautifulSoup
 from bs4.element import NavigableString, Tag
 from pycountry.db import Data
 
-LOG = logging.getLogger("cointainer_scraper_ecb")
-LOG.setLevel(logging.INFO)
-
-formatter = logging.Formatter(
-    "[{asctime}] [{levelname:<7}] [{name}] {message}",
-    datefmt="%d.%m.%Y %H:%M:%S",
-    style="{",
-)
-
-
-stream = logging.StreamHandler(sys.stdout)
-stream.setFormatter(formatter)
-LOG.addHandler(stream)
+LOG = logging.getLogger(__name__)
 
 ECB_BASE_URL = "https://www.ecb.europa.eu"
 ECB_TWO_EURO_URL = "https://www.ecb.europa.eu/euro/coins/comm/html"
@@ -512,10 +500,3 @@ def get_two_euro_commemorative_coins(
         )
         return []
     return _get_two_euro_commemorative_coins(response.content, lang, year)
-
-
-if __name__ == "__main__":
-    import pprint
-
-    coins = get_two_euro_commemorative_coins(year=2012)
-    pprint.pprint(coins)
